### Name: rsf.default
### Title: Random Survival Forest Entry Point
### Aliases: rsf.default rsf randomSurvivalForest
### Keywords: survival tree

### ** Examples

#------------------------------------------------------------
# Example 1:  Veteran's Administration lung cancer data
# Randomized trial of two treatment regimens for lung cancer
# See Kalbfleisch & Prentice

data(veteran, package = "randomSurvivalForest")
veteran.out <- rsf(Survrsf(time, status) ~ ., data = veteran)
print(veteran.out)
plot(veteran.out)

#------------------------------------------------------------
# Example 2:  More detailed call (veteran data)
# Use random splitting by invoking 'nsplit' option
# Use 'varUsed' option
# Use forest=TRUE option

#read the data, set various options
data(veteran, package = "randomSurvivalForest")
veteran.f <- as.formula(Survrsf(time, status) ~ .)
ntree <- 200
nsplit <- 3
varUsed <- "by.tree"
forest <- TRUE

# coerce 'celltype' as a factor and 'karnofsky score'
# as an ordered factor to illustrate factor useage
veteran$celltype <- factor(veteran$celltype,
    labels=c("squamous", "smallcell",  "adeno",  "large"))
veteran$karno <- factor(veteran$karno, ordered = TRUE)

# grow call
veteran2.out <- rsf(veteran.f, veteran, 
       ntree = ntree, nsplit = nsplit,
       varUsed = varUsed, forest = forest) 

# plot of ensemble survival for a single individual
surv.ensb <- t(exp(-veteran2.out$oob.ensemble))
plot(veteran2.out$timeInterest, surv.ensb[, 1])

# take a peek at the forest
head(veteran2.out$forest$nativeArray)

# average number of times a variable was split 
apply(veteran2.out$varUsed, 2, mean)

# partial plot of top variable
plot.variable(veteran2.out, partial = TRUE, npred = 1)

## Not run: 
##D #------------------------------------------------------------
##D # Example 3:  Competing risks
##D 
##D # Follicular Cell Lymphoma
##D data(follic, package = "randomSurvivalForest")
##D follic.out <- rsf(Surv(time, status) ~ ., follic, nsplit = 3, ntree = 400)
##D print(follic.out)
##D plot(follic.out, sorted = FALSE)
##D competing.risk(follic.out)
##D 
##D # Hodgkin's disease
##D data(hd, package = "randomSurvivalForest")
##D hd.out <- rsf(Surv(time, status) ~ ., hd, nsplit = 3, ntree = 400)
##D print(hd.out)
##D plot(hd.out, sorted = FALSE)
##D competing.risk(hd.out)
##D 
##D #------------------------------------------------------------
##D # Example 4:  Primary biliary cirrhosis (PBC) of the liver
##D # See Appendix D.1 of Fleming and Harrington
##D 
##D data(pbc, package = "randomSurvivalForest") 
##D pbc.out <- rsf(Surv(days, status) ~ ., pbc, nsplit = 3)
##D print(pbc.out)
##D 
##D #------------------------------------------------------------
##D # Example 5:  Same as Example 4, but with data imputation.
##D # Also see the R-wrapper "impute.rsf".
##D 
##D # rsf call with imputation
##D data(pbc, package = "randomSurvivalForest") 
##D pbc2.out <- rsf(Surv(days, status)~., pbc, 
##D                 nsplit = 3, na.action="na.impute")
##D print(pbc2.out)
##D 
##D # here's a nice wrapper to combine original data + imputed data
##D combine.impute <- function(object) {
##D   imputed.data <- cbind(cens = object$cens,
##D                         time = object$time,
##D                         object$predictors)
##D   if (!is.null(object$imputedIndv)) {
##D     imputed.data[object$imputedIndv, ] <- object$imputedData
##D   }
##D   colnames(imputed.data)[c(2,1)] <- all.vars(object$formula)[1:2]
##D   imputed.data
##D }
##D 
##D # combine original data + imputed data
##D pbc.imputed.data <- combine.impute(pbc2.out)
##D 
##D # iterate the missing data algorithm
##D # compare to non-iterated algorithm
##D pbc3.out <- rsf(Surv(days, status)~., pbc, nsplit=5,  
##D          na.action="na.impute", nimpute = 3)
##D pbc.iterate.imputed.data <- combine.impute(pbc3.out)
##D tail(pbc.imputed.data)
##D tail(pbc.iterate.imputed.data)
##D 
##D #------------------------------------------------------------
##D # Example 6:  German breast cancer data
##D # Variable selection using minimal depth
##D 
##D data(breast, package = "randomSurvivalForest")
##D breast.out <- rsf(Surv(time, cens) ~ . , breast,
##D             forest = TRUE, nsplit = 3)
##D 
##D # use varSel to select variables
##D # see the help file of varSel for details/examples
##D 
##D breast.vs <- varSel(object=breast.out)
##D 
##D #------------------------------------------------------------
##D # Example 7:  Compare Cox regression to RSF using PBC data. 
##D # OOB estimate of C-index for Cox based on 100 bootstraps.
##D # Assumes "Hmisc" and "survival" libraries are loaded. 
##D 
##D if (library("survival", logical.return = TRUE) 
##D     & library("Hmisc", logical.return = TRUE))
##D {
##D   data(pbc, package = "randomSurvivalForest")
##D   pbc3.out <- rsf(Surv(days, status)~., pbc, nsplit = 10, mtry = 2)
##D   B <- 100 
##D   cox.err <- rep(NA, B) 
##D   cox.f <- as.formula(Surv(days, status)~.)  
##D   pbc.data <- pbc[apply(is.na(pbc), 1, sum) == 0,] ##remove NA's 
##D   cat("Out-of-bag Cox Analysis ...", "\n")
##D   for (b in 1:B) {
##D     cat("Cox bootstrap:", b, "\n") 
##D     bag.sample <- sample(1:nrow(pbc.data),
##D                          nrow(pbc.data),
##D                          replace = TRUE) 
##D     oob.sample <- setdiff(1:nrow(pbc.data), bag.sample)
##D     train <- pbc.data[bag.sample,]
##D     test <- pbc.data[oob.sample,]
##D     cox.out <- coxph(cox.f, train)
##D     cox.out <- tryCatch({coxph(cox.f, train)}, error=function(ex){NULL})
##D     if (is.list(cox.out)) {
##D       cox.predict <- predict(cox.out, test)
##D       cox.err[b] <- rcorr.cens(cox.predict, 
##D               Surv(pbc.data$days[oob.sample],
##D               pbc.data$status[oob.sample]))[1]
##D     }
##D   }
##D   cat("Error rates:", "\n")
##D   cat("Random Survival Forests:", pbc3.out$err.rate[pbc3.out$ntree], "\n")
##D   cat("         Cox Regression:", mean(cox.err, na.rm = TRUE), "\n")
##D }
## End(Not run)



